<?php
/************************************************************************
 * Mailer v0.2.1-FINAL                                Start: 08/29/2003 *
 * ===================                          Last change: 11/11/2004 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : install-inc.php                                  *
 * -------------------------------------------------------------------- *
 * Short description : Functions for installation procedure             *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Funktionen fuer die Installationsroutine         *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * Copyright (c) 2009 - 2013 by Mailer Developer Team                   *
 * For more information visit: http://mxchange.org                      *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if ((!defined('__SECURITY')) || (!isInstaller())) {
	die();
} // END - if

// Load extension timezone
loadExtension('timezone', 'test');

// Set config entry
setConfigEntry('timezone', 'Europe/Berlin');

// Init some things
FILTER_INIT_TIMEZONE(array());
FILTER_INIT_RANDOMIZER();
FILTER_INIT_RANDOM_NUMBER();

// Init variables
$GLOBALS['install_mysql'] = array();
if ((isPostRequestElementSet('mysql')) && (ifPostContainsSelections('mysql'))) {
	// Transfer 'mysql' array
	$GLOBALS['install_mysql'] = postRequestElement('mysql');
} // END - if

// Check if both passwords from SMTP are matching
if ((isGetRequestElementSet('install_page') && (getRequestElement('install_page') == 5))) {
	// Okay, we have to check it
	if (isPostRequestElementSet('smtp_user') && (!isPostRequestElementSet('smtp_host'))) {
		// Hostname not set
		addToInstallContent('<div class="para">{--INSTALLER_SMTP_HOSTNAME_EMPTY--}</div>');
		setGetRequestElement('install_page', 3);
	} // END - if

	if ((!isPostRequestElementSet('smtp_password1')) && (isPostRequestElementSet('smtp_password2'))) {
		// Password is empty
		addToInstallContent('<div class="para">{--INSTALLER_SMTP_PASSWORD1_EMPTY--}</div>');
		setGetRequestElement('install_page', 3);
	} // END - if

	if ((isPostRequestElementSet('smtp_password1')) && (!isPostRequestElementSet('smtp_password2'))) {
		// Password repeat is empty
		addToInstallContent('<div class="para">{--INSTALLER_SMTP_PASSWORD2_EMPTY--}</div>');
		setGetRequestElement('install_page', 3);
	} // END - if

	if (postRequestElement('smtp_password1') != postRequestElement('smtp_password1')) {
		// Passwords are not matching
		addToInstallContent('<div class="para">{--INSTALLER_SMTP_PASS_MISMATCH--}</div>');
		setGetRequestElement('install_page', 3);
	} // END - if
} // END - if

// Is the mailer installed or no admin registered so far?
if ((!isInstalled()) || (!isAdminRegistered())) {
	// Construct include file name
	$inc = 'inc/install/install_page_' . getRequestElement('install_page') . '.php';

	// Is the include file there?
	if (isIncludeReadable($inc)) {
		// Then load it
		loadIncludeOnce($inc);
	} else {
		// Not found, may be invalid page
		logDebugMessage(__FILE__, __LINE__, sprintf('Wrong install_page=%s detected', getRequestElement('install_page')));
		addTemplateToInstallContent('admin_settings_unsaved', '{%message,INSTALLER_WRONG_PAGE=' . getRequestElement('install_page') . '%}');
	}
} else {
	// Already installed!
	addFatalMessage(__FILE__, __LINE__, '{--MAILER_ALREADY_INSTALLED--}');
}

// [EOF]
?>
