<?php
/************************************************************************
 * Mailer v0.2.1-FINAL                                Start: 09/09/2008 *
 * ===================                          Last change: 09/09/2008 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : load-modules.php                                 *
 * -------------------------------------------------------------------- *
 * Short description : Load more cache files                            *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Mehr Cache-Dateien nachladen                     *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * Copyright (c) 2009 - 2013 by Mailer Developer Team                   *
 * For more information visit: http://mxchange.org                      *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if (!defined('__SECURITY')) {
	die();
} elseif (isInstaller()) {
	// Do not run in installation phase
	//* DEBUG: */ logDebugMessage(__FILE__, __LINE__, 'Run from installation phase.');
	return FALSE;
} elseif (!isExtensionInstalled('mods')) {
	// Do not run if ext-mods is missing
	return FALSE;
}

// Next cached table is the module registry (mod_reg)...
if (($GLOBALS['cache_instance']->loadCacheFile('modules')) && ($GLOBALS['cache_instance']->extensionVersionMatches('sql_patches'))) {
	// Load cache
	$GLOBALS['cache_array']['modules'] = $GLOBALS['cache_instance']->getArrayFromCache();

	// Rewrite module cache
	$modArray = $GLOBALS['cache_array']['modules'];

	// Do only process valid arrays
	if (!isset($modArray['module'])) {
		// Try to remove the cache file
		$GLOBALS['cache_instance']->removeCacheFile();

		// We should fix this
		reportBug(__FILE__, __LINE__, 'modArray=<pre>' . print_r($modArray, TRUE) . '</pre>Please try to reload to fix this.');
	} // END - if

	// Rewrite some parts
	foreach ($modArray['module'] as $key => $mod) {
		// Default without sql_patches
		$entries = array('id', 'title', 'locked', 'admin_only', 'mem_only');

		// Is ext-sql_patches newer or equal 0.3.6?
		if (isExtensionInstalledAndNewer('sql_patches', '0.3.6')) {
			// Add 'has_menu'
			array_push($entries, 'has_menu');
		} // END - if

		// Add all
		foreach ($entries as $entry) {
			// Is the entry set?
			if (isset($GLOBALS['cache_array']['modules'][$entry][$key])) {
				// Transfer it
				$GLOBALS['cache_array']['modules'][$entry][$mod] = $modArray[$entry][$key];

				// And delete cache
				unset($GLOBALS['cache_array']['modules'][$entry][$key]);
			} else {
				// Log this for debug purposes
				logDebugMessage(basename(__FILE__), __LINE__, 'Entry not found. module=' . $mod . ',key=' . $key . ',entry=' . $entry);
			}
		} // END - foreach
	} // END - foreach
	unset($modArray);
} elseif ((isHtmlOutputMode()) || (isAjaxOutputMode()) || (isRawOutputMode())) {
	// Create cache file here
	$GLOBALS['cache_instance']->init();

	// Is there up-to-date ext-sql_patches?
	if (isExtensionInstalledAndNewer('sql_patches', '0.3.6')) {
		// Yes, has_menu shall be there
		$result = sqlQuery('SELECT
	`id`,
	`module`,
	`title`,
	`locked`,
	`admin_only`,
	`title`,
	`mem_only`,
	`has_menu`
FROM
	`{?_MYSQL_PREFIX?}_mod_reg`
ORDER BY
	`module` ASC', __FILE__, __LINE__);
	} else {
		// Not recent enough ext-sql_patches ...
		$result = sqlQuery('SELECT
	`id`,
	`module`,
	`title`,
	`locked`,
	`admin_only`,
	`title`,
	`mem_only`
FROM
	`{?_MYSQL_PREFIX?}_mod_reg`
ORDER BY
	`module` ASC', __FILE__, __LINE__);
	}

	// ... and load all entries
	while ($content = sqlFetchArray($result)) {
		// Add row to cache file
		$GLOBALS['cache_instance']->addRow($content);
	} // END - while

	// Free memory
	sqlFreeResult($result);

	// Close the cache
	$GLOBALS['cache_instance']->storeExtensionVersion('mods');
	$GLOBALS['cache_instance']->storeExtensionVersion('sql_patches');
	$GLOBALS['cache_instance']->finalize();
}

// [EOF]
?>
