<?php
/************************************************************************
 * Mailer v0.2.1-FINAL                                Start: 05/08/2004 *
 * ===================                          Last change: 08/12/2004 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : what-list_payouts.php                            *
 * -------------------------------------------------------------------- *
 * Short description : List member's payout requests                    *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Auflistung der Auszahlungsanfragen               *
 * -------------------------------------------------------------------- *
 * $Revision::                                                        $ *
 * $Date::                                                            $ *
 * $Tag:: 0.2.1-FINAL                                                 $ *
 * $Author::                                                          $ *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * Copyright (c) 2009 - 2013 by Mailer Developer Team                   *
 * For more information visit: http://mxchange.org                      *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if ((!defined('__SECURITY')) || (!isAdmin())) {
	die();
} // END - if

// Add description as navigation point
addYouAreHereLink('admin', __FILE__);

if (isGetRequestElementSet('pid')) {
	// First let's get the member's id
	$result = sqlQueryEscaped("SELECT `userid`, `target_account`, `payout_total`, `payout_timestamp`, `password` FROM `{?_MYSQL_PREFIX?}_user_payouts` WHERE `id`=%s LIMIT 1",
		array(getRequestElement('pid')), __FILE__, __LINE__);
	list($userid, $tuserid, $points, $tstamp, $tpass) = sqlFetchRow($result);
	sqlFreeResult($result);

	// Obtain some data
	if (!isGetRequestElementSet('task') && (!empty($userid)) && (isValidId($userid))) {
		// Get task id from database
		$result = sqlQueryEscaped("SELECT `id` FROM `{?_MYSQL_PREFIX?}_task_system` WHERE `userid`=%s AND `task_type`='PAYOUT_REQUEST' AND `task_created`=%s LIMIT 1",
			array(bigintval($userid), bigintval($tstamp)), __FILE__, __LINE__);
		list($taskId) = sqlFetchRow($result);
		sqlFreeResult($result);
		if (empty($taskId)) $taskId = '0';
	} elseif (!isValidId($userid)) {
		// Cannot obtain member id!
		displayMessage('{--ADMIN_PAYOUT_FAILED_OBTAIN_USERID--}');
	} else {
		// Get task id from URL
		$taskId = getRequestElement('task');
	}

	if ((!empty($taskId)) && (!empty($userid)) && (isValidId($userid))) {
		// Load user's data
		if (!fetchUserData($userid)) {
			// Abort here because it is not valid!
			reportBug(__FILE__, __LINE__, 'No user account ' . $userid . ' found.');
		} // END - if

		if ((getRequestElement('do') == 'accept') && (getUserData('email') != '')) {
			// Ok, now we can output the form or execute accepting
			if (isFormSent()) {
				// Obtain payout type and other data
				$result = sqlQueryEscaped("SELECT `payout_id` FROM `{?_MYSQL_PREFIX?}_user_payouts` WHERE `id`=%s LIMIT 1",
					array(bigintval(getRequestElement('pid'))), __FILE__, __LINE__);

				// Load ptype (id)
				list($ptype) = sqlFetchRow($result);

				// Free result
				sqlFreeResult($result);

				if (!empty($ptype)) {
					// Obtain data from payout type
					$result = sqlQueryEscaped("SELECT
	`from_account`,
	`from_pass`,
	`engine_url`,
	`engine_ret_ok`,
	`engine_ret_failed`,
	`pass_enc`,
	`allow_url`
FROM
	`{?_MYSQL_PREFIX?}_payout_types`
WHERE
	`id`=%s
LIMIT 1",
						array(bigintval($ptype)), __FILE__, __LINE__);

					// Load data
					$data = sqlFetchArray($result);

					// Free result
					sqlFreeResult($result);

					if (!empty($data['engine_url'])) {
						// Ok, run URL...
						switch ($data['pass_enc']) {
							case 'md5':
								$data['from_pass'] = md5($data['from_pass']);
								$tpass = md5($tpass);
								break;

							case 'base64':
								$data['from_pass'] = base64_encode($data['from_pass']);
								$tpass = base64_encode($tpass);
								break;
						} // END - switch

						// Transfer variables...
						$reason = encodeString(getMessage('ADMIN_PAYOUT_REASON'), FALSE);

						// Execute transfer
						$ret = sendHttpGetRequest($data['engine_url']);
					} else {
						// No URL to run
						$ret[0] = $data['engine_ret_ok'];
					}

					if ($ret[0] == $data['engine_ret_ok']) {
						// Clear task
						if (isValidId($taskId)) {
							runFilterChain('solve_task', $taskId);
						} // END - if

						// Clear payout request
						sqlQueryEscaped("UPDATE `{?_MYSQL_PREFIX?}_user_payouts` SET `status`='ACCEPTED' WHERE `id`=%s LIMIT 1",
							array(bigintval(getRequestElement('pid'))), __FILE__, __LINE__);

						// Send out mail
						$message = loadEmailTemplate('member_payout_accepted', postRequestElement('text'), $userid);

						// Output message
						if ($data['allow_url'] == 'Y') {
							// Banner / Textlink request
							displayMessage('{--ADMIN_PAYOUT_BANNER_ACCEPTED_NOTIFIED--}');
						} else {
							// Normal request
							displayMessage('{--ADMIN_PAYOUT_ACCEPTED_NOTIFIED--}');
						}

						// Finally send mail
						sendEmail(getUserData('userid'), '{--MEMBER_PAYOUT_ACCEPTED_SUBJECT--}', $message);
					} else {
						// Something goes wrong... :-(
						$content = implode('<br />', $ret);
						loadTemplate('admin_payout_failed_transfer', FALSE, $content);
					}
				} else {
					// Cannot load payout id
					displayErrorMessage('{--ADMIN_PAYOUT_FAILED_OBTAIN_PAYOUT_ID--}');
				}
			} else {
				// Prepare content
				$content = array(
					'task' => $taskId,
					'pid'  => bigintval(getRequestElement('pid')),
					'user' => '<a href="' . generateEmailLink(getUserData('email'), 'user_data') . '">{%pipe,translateGender=' . getUserData('gender') . '%} ' . getUserData('surname') . ' ' . getUserData('family') . '</a>',
				);

				// Load template
				loadTemplate('admin_payout_accept_form', FALSE, $content);
			}
		} elseif ((getRequestElement('do') == 'reject') && (getUserData('email') != '')) {
			// Ok, now we can output the form or execute rejecting
			if (isFormSent()) {
				if (isValidId($taskId)) {
					// Clear task
					runFilterChain('solve_task', $taskId);
				} // END - if

				// Clear payout request
				sqlQueryEscaped("UPDATE `{?_MYSQL_PREFIX?}_user_payouts` SET `status`='REJECTED' WHERE `id`=%s LIMIT 1",
					array(bigintval(getRequestElement('pid'))), __FILE__, __LINE__);

				// Send out mail
				$message = loadEmailTemplate('member_payout_rejected', postRequestElement('text'), $userid);

				// Output message
				displayMessage('{--ADMIN_PAYOUT_REJECTED_NOTIFIED--}');

				// Finally send mail
				sendEmail(getUserData('userid'), '{--MEMBER_PAYOUT_REJECTED_SUBJECT--}', $message);
			} else {
				// Prepare content
				$content = array(
					'task' => $taskId,
					'pid'  => bigintval(getRequestElement('pid')),
					'user' => '<a href="' . generateEmailLink(getUserData('email'), 'user_data') . '">{%pipe,translateGender=' . getUserData('gender') . '%} ' . getUserData('surname') . ' ' . getUserData('family') . '</a>',
				);

				// Load template
				loadTemplate('admin_payout_reject_form', FALSE, $content);
			}
		} else {
			// Cannot load user data
			displayMessage('{--ADMIN_PAYOUT_FAILED_OBTAIN_USERDATA--}');
		}
	} elseif (!isValidId($taskId)) {
		// Failed loading task id
		displayMessage('{--ADMIN_PAYOUT_FAILED_OBTAIN_TASK_ID--}');
	}
} else {
	if (getRequestElement('do') == 'delete') {
		// Delete all requests
		$result = sqlQuery("TRUNCATE `{?_MYSQL_PREFIX?}_user_payouts`", __FILE__, __LINE__);
	} // END - if

	// Search for payouts
	$result = sqlQuery('SELECT
	`p`.`id`,
	`p`.`userid`,
	`p`.`payout_total`,
	`p`.`target_account`,
	`p`.`target_bank`,
	`t`.`type`,
	`p`.`payout_timestamp`,
	`p`.`status`,
	`t`.`allow_url`
	`p`.`target_url`,
	`p`.`link_text`
	`p`.`banner_url`
FROM
	`{?_MYSQL_PREFIX?}_user_payouts` AS `p`
LEFT JOIN
	`{?_MYSQL_PREFIX?}_payout_types` AS `t`
ON
	`p`.`payout_id`=`t`.`id`
ORDER BY
	`p`.`payout_timestamp` DESC', __FILE__, __LINE__);

	if (!ifSqlHasZeroNums($result)) {
		// List found payouts
		$OUT = '';
		while ($content = sqlFetchArray($result)) {
			if ($content['status'] == 'NEW') {
				// Generate links for direct accepting and rejecting
				$content['status'] = '<a href="{%url=modules.php?module=admin&amp;what=list_payouts&amp;do=accept&amp;pid=' . $content['id'] . '%}">{--ADMIN_PAYOUT_ACCEPT_PAYOUT--}</a>|<a href="{%url=modules.php?module=admin&amp;what=list_payouts&amp;do=reject&amp;pid=' . $content['id'] . '%}">{--ADMIN_PAYOUT_REJECT_PAYOUT--}</a>';
			} else {
				// Translate status
				$content['status'] = translatePayoutStatus($content['status']);
			}

			// Nothing entered must be secured in member/what-payputs.php !
			if ($content['allow_url'] == 'Y') {
				// Banner/Textlink views/clicks request
				if (!empty($content['banner_url'])) {
					// Load template for the banner
					$content['target_account'] = loadTemplate('admin_list_payouts_banner', TRUE, $content);
				} else {
					// Textlink
					$content['target_account'] = loadTemplate('admin_list_payouts_txt', TRUE, $content);
				}

				// Admins can addionally test the URL for framekillers
				$content['target_bank'] = '<a href="' . generateFrametesterUrl($content['target_url']) . '" target="_blank">{--CLICK_HERE--}</a>';
			} // END - if

			// Add/Translate some data
			$content['payout_timestamp'] = generateDateTime($content['payout_timestamp'], 2);

			// Add row and switch color
			$OUT .= loadTemplate('admin_list_payouts_row', TRUE, $content);
		} // END - while

		// Free memory
		sqlFreeResult($result);

		// Load final template
		loadTemplate('admin_list_payouts', FALSE, $OUT);
	} else {
		// No payout requests are sent so far
		displayMessage('{--ADMIN_PAYOUT_NO_REQUESTS_FOUND--}');
	}
}

// [EOF]
?>
